%define major 1
%define libname %mklibname tomcrypt %{major}
%define libname_devel %mklibname tomcrypt -d

%define tommath_version 1.0

Name:           libtomcrypt
Version:        1.18.2
Release:        %mkrel 6
Summary:        Comprehensive, portable cryptographic toolkit
Group:          System/Libraries
License:        Public Domain
URL:            https://www.libtom.net/LibTomCrypt/
Source0:        https://github.com/libtom/libtomcrypt/releases/download/v%{version}/crypt-%{version}.tar.xz
Patch0:         libtomcrypt-CVE-2019-17362.patch
BuildRequires:  ghostscript
BuildRequires:  ghostscript-dvipdf
BuildRequires:  latex
BuildRequires:  libtool
BuildRequires:  tetex-dvips
BuildRequires:  tetex-latex
BuildRequires:  texlive-texmf
BuildRequires:  pkgconfig(libtommath) >= %{tommath_version}

%description
A comprehensive, modular and portable cryptographic toolkit that
provides developers with a vast array of well known published block
ciphers, one-way hash functions, chaining modes, pseudo-random number
generators, public key cryptography and a plethora of other routines.

Designed from the ground up to be very simple to use. It has a modular
and standard API that allows new ciphers, hashes and PRNGs to be added
or removed without change to the overall end application. It features
easy to use functions and a complete user manual which has many source
snippet examples.

%package -n	%{libname}
Summary:        Comprehensive, portable cryptographic toolkit
Group:          System/Libraries

%description -n %{libname}
A comprehensive, modular and portable cryptographic toolkit that
provides developers with a vast array of well known published block
ciphers, one-way hash functions, chaining modes, pseudo-random number
generators, public key cryptography and a plethora of other routines.

Designed from the ground up to be very simple to use. It has a modular
and standard API that allows new ciphers, hashes and PRNGs to be added
or removed without change to the overall end application. It features
easy to use functions and a complete user manual which has many source
snippet examples.

%package -n	%{libname_devel}
Summary:        Development files for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       tommath-devel >= %{tommath_version}
Provides:       tomcrypt-devel = %{version}-%{release}

%description -n %{libname_devel}
The %{libname_devel} package contains libraries and header files for
developing applications that use %{name}.

%prep
%setup -q
%autopatch -p1

# Fix pkgconfig path
sed -i \
    -e 's|^libdir=.*|libdir=%{_libdir}|g' \
    %{name}.pc.in

%build
%set_build_flags
export CFLAGS="%{optflags} -DLTM_DESC -DUSE_LTM"
%make_build -f makefile docs
%make_build LIBPATH=%{_libdir} -f makefile.shared

%check
%__make LIBPATH=%{_libdir} -f makefile.shared test
./test

%install
%make_install INSTALL_OPTS="-m 755" PREFIX=%{_prefix} INCPATH=%{_includedir} LIBPATH=%{_libdir} -f makefile.shared

find %{buildroot} -name "*.la" -delete
find %{buildroot} -name '*.a' -delete

%files -n %{libname}
%doc LICENSE
%{_libdir}/lib*.so.%{major}{,.*}

%files -n %{libname_devel}
%doc doc/crypt.pdf
%{_includedir}/tomcrypt*.h
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc


%changelog
* Fri Apr 01 2022 umeabot <umeabot> 1.18.2-6.mga9
+ Revision: 1840021
- Mageia 9 Mass Rebuild

* Sat Jun 12 2021 wally <wally> 1.18.2-5.mga9
+ Revision: 1730473
- install header files under /usr/include and fix paths in pkgconf .pc file (mga#29105)

* Tue Feb 18 2020 umeabot <umeabot> 1.18.2-4.mga8
+ Revision: 1539229
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Wed Dec 04 2019 daviddavid <daviddavid> 1.18.2-3.mga8
+ Revision: 1464202
- add upstream patch to fix CVE-2019-17362 (mga#25808)

* Sun Sep 23 2018 umeabot <umeabot> 1.18.2-2.mga7
+ Revision: 1299189
- Mageia 7 Mass Rebuild

* Sat Jul 21 2018 danf <danf> 1.18.2-1.mga7
+ Revision: 1244745
- Updated to 1.18.2. Major changes include:
  - Fix Side Channel Based ECDSA Key Extraction (CVE-2018-12437)
  - Fix potential stack overflow when DER flexi-decoding (CVE-2018-0739)
  - Fix two-key 3DES
  - Fix accelerated CTR mode
  - Fix Fortuna PRNG
  - Fix & re-factor crypt_list_all_sizes() and crypt_list_all_constants()

* Sun Jan 28 2018 danf <danf> 1.18.1-1.mga7
+ Revision: 1197511
- Upgraded to ver. 1.18.1 (SONAME bump)
  Dropped unneeded patches

* Mon Oct 31 2016 daviddavid <daviddavid> 1.17-11.mga6
+ Revision: 1064253
- add debian patch to fix CVE-2016-6129 (mga#19305)

* Thu Oct 20 2016 daviddavid <daviddavid> 1.17-10.mga6
+ Revision: 1062817
- fix build against new texlive 2016

* Sat Apr 09 2016 philippem <philippem> 1.17-9.mga6
+ Revision: 999894
- rebuild for new libtommath

* Thu Feb 11 2016 umeabot <umeabot> 1.17-8.mga6
+ Revision: 955799
- Mageia 6 Mass Rebuild
+ danf <danf>
- Updated URLs

* Wed Oct 15 2014 umeabot <umeabot> 1.17-7.mga5
+ Revision: 746159
- Second Mageia 5 Mass Rebuild

* Sun Oct 05 2014 danf <danf> 1.17-6.mga5
+ Revision: 736939
- Added respect-ldflags.patch to use the standard LDFLAGS during the build

* Sun Oct 05 2014 danf <danf> 1.17-5.mga5
+ Revision: 736931
- Removed static library subpackage which doesn't build
- Enabled the test suite
- Import Mandriva package


* Sun Sep 09 2012 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.17-4
+ Revision: 816583
- don't drop '-O3 -funroll-loops' from compiler flags
- workaround stripping issue with test for now..
- cleanups

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Sun Aug 17 2008 David Walluck <walluck@mandriva.org> 1.17-2mdv2009.0
+ Revision: 272862
- fix Requires

* Mon Aug 11 2008 David Walluck <walluck@mandriva.org> 1.17-1mdv2009.0
+ Revision: 270853
- BuildRequires: libtool
- really fix Requires
- fix Requires
- fix tommath requirements
- import libtomcrypt

